abacusai.template_node_details — AbacusAI documentation

# abacusai.template_node_details

## Classes

`TemplateNodeDetails` | Details about WorkflowGraphNode object and notebook code for adding template nodes in workflow.

## Module Contents

class abacusai.template_node_details.TemplateNodeDetails(client, notebookCode=None, workflowGraphNode={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Details about WorkflowGraphNode object and notebook code for adding template nodes in workflow.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - notebookCode (list) – The boilerplate code that needs to be shown in notebook for creating workflow graph node using corresponding template.

    - workflowGraphNode (WorkflowGraphNode) – The workflow graph node object corresponding to the template.

  notebook_code
  workflow_graph_node
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict